"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServiceCollectionFactory = void 0;
const constants_1 = require("../constants");
const services_1 = require("../services");
const object_1 = require("../services/object");
const storage_1 = require("../services/storage");
const utils_1 = require("../utils");
const agileServiceFactory_1 = require("./agileServiceFactory");
const repoServiceFactory_1 = require("./repoServiceFactory");
class ServiceCollectionFactory {
    /**
     * Create collection of shared services
     *
     * @returns {ServiceCollection} Service Collection
     */
    static create() {
        return __awaiter(this, void 0, void 0, function* () {
            const localFileStorageService = new storage_1.FileStorageService(process.cwd());
            const parameterService = new object_1.ObjectService(localFileStorageService);
            // TODO: This should change, but it will likely take a large refactor.
            //
            // There's a desire to pass options to commands. Some of the options include
            // filepaths to configuration and different ways to read in configuration
            // files.
            //
            // With DI working as it does now, those options are on commands themselves.
            // But we're instantiating object services before the options are getting
            // evaluated.
            //
            // I've created issue #70 to track this.
            // TODO - removing retrieval of parameters file for now - will interpolate more dynamically in future
            const backlogItemTemplateService = new object_1.ObjectService(localFileStorageService);
            const contentService = new object_1.ObjectService(localFileStorageService);
            const playbookOwner = utils_1.Config.getValue(constants_1.ConfigKey.PlaybookOwnerName);
            const playbookRepoName = utils_1.Config.getValue(constants_1.ConfigKey.PlaybookRepoName);
            return {
                getAgileService: agileServiceFactory_1.AgileServiceFactory.get,
                getRepoService: repoServiceFactory_1.RepoServiceFactory.get,
                getPlaybookService: (options) => {
                    const repoService = repoServiceFactory_1.RepoServiceFactory.get({
                        repoProvider: services_1.RepoServiceProvider.GitHub,
                        accessToken: options.playbookAccessToken || "",
                        baseUrl: `https://github.com/${playbookOwner}`,
                        projectName: playbookRepoName,
                    });
                    return new services_1.CodeWithPlaybookService(repoService, contentService);
                },
                backlogItemTemplateService,
                parameterService,
                contentService,
            };
        });
    }
}
exports.ServiceCollectionFactory = ServiceCollectionFactory;
